EMBEDDED_FILES = {
    "bin__jsii-runtime.js": "bin/jsii-runtime.js",
    "bin__jsii-runtime.js.map": "bin/jsii-runtime.js.map",
    "lib__program.js": "lib/program.js",
    "lib__program.js.map": "lib/program.js.map",
}

ENTRYPOINT = "bin__jsii-runtime.js"

__all__ = ["EMBEDDED_FILES", "ENTRYPOINT"]
